@@ -116,7 +116,13 @@ setMethod("rsat_list_data",
       message("There is no processed images in the rtoi.")
       return(NULL)
     }
-    as.data.frame(do.call(rbind, allvariables))
+    #as.data.frame(do.call(rbind, allvariables))
+    #TODO change this and make it work well
+    tmp <- sapply(as.data.frame(do.call(rbind, allvariables)), function(x) unlist(x))
+    rownames(tmp) <- NULL
+    df <- as.data.frame(tmp)
+    row.names(df) <- NULL
+    df
   }
 )
 
